==> better-admin-ui-vue-0.0.7.tgz: package/es/components/SearchBar/SearchBar.js <==
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * @Date: 2020/11/24 2:44 下午
 * @Author: Fioanna
 * @Description: 高级搜索表单
 * 支持的类型：InputNumber, Input, Radio, Select, Suggest, DateRange, CompactInput
 */
import moment from 'moment';
import ARow from 'ant-design-vue/es/row';
import ACol from 'ant-design-vue/es/col';
import ACard from 'ant-design-vue/es/card';
import AButton from 'ant-design-vue/es/button';
import AFormModal from 'ant-design-vue/es/form-model';
import { FORM_ITEM_TYPE, FormMixin } from '../Form';
import EMixedInput from '../MixedInput';
import searchBarProps from './types';
import { COL_2_ITEM_LIST, SELECT_ALL_VALUE, SEARCH_TYPE } from './constants';
import '../Form/style.less';
import './style.less';
var COL_TOTAL = 24; // 默认一行分为24份，可除尽1、2、3、4、6、8、12、24

var MD_COL = 2; // 栅格md

var XL_COL = 4; // 栅格xl

var AFormModalItem = AFormModal.Item; // 默认的展示时间格式

var DEFAULT_SHOW_FORMAT = 'YYYY-MM-DD HH:mm:ss';
export default {
  name: 'ESearchBar',
  mixins: [FormMixin],
  props: searchBarProps,
  computed: {
    // 表单v-bind的所有props
    formModelBind: function formModelBind() {
      return {
        layout: 'inline',
        model: this.form
      };
    }
  },
  render: function render() {
    var h = arguments[0];

    if (this.hasFieldList) {
      return h(ACard, {
        "class": "e-search-bar e-form"
      }, [h(AFormModal, _mergeJSXProps([{
        ref: "advancedForm"
      }, {
        props: this.formModelBind
      }]), [h(ARow, {
        attrs: {
          gutter: {
            xs: 8,
            sm: 16,
            md: 24
          }
        }
      }, [this._renderFormContent()])])]);
    }

    return null;
  },
  methods: {
    // 时间选择器
    _parseDateRange: function _parseDateRange(item, props) {
      props.showFormat = props.showFormat || DEFAULT_SHOW_FORMAT;
      props.valueFormat = props.valueFormat || null;

      if (props.showFormat === DEFAULT_SHOW_FORMAT) {
        // 如果是默认的有时分秒的格式则设定展示time
        props.showTime = true;
      } // 一般搜索栏都有时间选择限制
      // 如果没有明确说明不需要，且又未传入的，则默认设置一个disabledDate


      if (item.needDisabledDate !== false && !props.disabledDate) {
        // 限制的范围天数
        var limitRangeDays = item.limitRangeDays;
        var limitMethod = limitRangeDays ? function (current) {
          return current < moment().subtract(limitRangeDays, 'days').endOf('date');
        } : function () {
          return false;
        };

        props.disabledDate = function (current) {
          // 可以取到当天最后一秒
          return current && (current > moment().endOf('date') || limitMethod(current));
        };
      }
    },

    /**
     * 刷新普通下拉选项列表，可继承
     */
    _refreshSelectList: function _refreshSelectList(selectList, item, props) {
      // 需要添加全部选项
      if (item.needAll && selectList && selectList.length > 0) {
        // console.log('~~~selectList~~~', selectList)
        var valueName = props.valueName || 'value';

        if (selectList[0][valueName] !== SELECT_ALL_VALUE) {
          var _selectList$unshift;

          selectList.unshift((_selectList$unshift = {}, _defineProperty(_selectList$unshift, valueName, SELECT_ALL_VALUE), _defineProperty(_selectList$unshift, props.labelName || 'label', '全部'), _selectList$unshift));
        }
      }
    },

    /**
     * 刷新字典下拉选项列表，可继承
     */
    _refreshDictSelectList: function _refreshDictSelectList(selectList, item, props) {
      var itemDom = this.$refs[item.key]; // 直接更新下拉组件中的数据

      if (itemDom) {
        this._refreshSelectList(selectList, item, props);

        itemDom.setOptionList(selectList);
      }
    },
    // 初始化表单的单项
    _renderFormItem: function _renderFormItem(fieldItem, index) {
      var h = this.$createElement;
      var itemCol = 1;

      if (COL_2_ITEM_LIST.includes(fieldItem.type)) {
        itemCol = fieldItem.col || 2;
      }

      return h(ACol, {
        attrs: {
          sm: COL_TOTAL,
          md: COL_TOTAL / MD_COL * itemCol,
          xl: COL_TOTAL / XL_COL * itemCol
        }
      }, [h(AFormModalItem, {
        key: index,
        attrs: {
          label: fieldItem.label,
          prop: fieldItem.key + '',
          required: fieldItem.required,
          rules: fieldItem.rules
        }
      }, [this._renderFormItemContent(fieldItem)])]);
    },
    // 初始化表单footer的按钮部分
    _renderFormFooter: function _renderFormFooter() {
      var h = this.$createElement;
      var btnList = [h(AButton, {
        attrs: {
          icon: "search",
          type: "primary"
        },
        on: {
          "click": this._confirm
        }
      }, ["\u67E5\u8BE2"])];

      if (this.$props.needReset) {
        btnList.push(h(AButton, {
          attrs: {
            icon: "redo"
          },
          on: {
            "click": this.reset
          }
        }, ["\u91CD\u7F6E"]));
      }

      return h(ACol, {
        attrs: {
          sm: COL_TOTAL,
          md: COL_TOTAL / MD_COL,
          xl: COL_TOTAL / XL_COL
        }
      }, [h(AFormModalItem, {
        style: "margin:0;"
      }, [h("span", {
        "class": "search-btn-wrapper right"
      }, [btnList])])]);
    },
    // 初始化组合输入框
    _renderCompactInput: function _renderCompactInput(fieldItem) {
      var _this = this;

      var h = this.$createElement;
      return h(EMixedInput, _mergeJSXProps2([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value) {
            _this._emitChange(fieldItem.key, value);
          }
        }
      }]));
    },

    /**
     * 时间区间选择变动
     * @param key form的key
     * @param {Array} dates 指定日期格式的字符串，无格式则返回moment
     * @private
     */
    _dateRangeChange: function _dateRangeChange(item, dates) {
      var _this2 = this;

      var keys = item.keys,
          key = item.key;
      this.$set(this.form, key, 'date');
      dates.forEach(function (date, index) {
        if (item.showFormat !== DEFAULT_SHOW_FORMAT) {
          var momentParse = index === 0 ? 'startOf' : 'endOf';
          date[momentParse]('date');
        }

        _this2._emitChange(keys[index], date);
      });
    },

    /**
     * 点击查询
     * @private
     */
    _confirm: function _confirm() {
      this.$emit('search', this.getValue());
    },
    // 判断value是否为空
    _valueError: function _valueError(value) {
      return !value && value !== 0;
    },

    /**
     * 获取表单数据
     * @returns {form|{}}
     */
    getValue: function getValue() {
      var _this3 = this;

      var resForm = {};
      var searchKeys = [];

      var _loop = function _loop(key) {
        var value = _this3.form[key]; // 判断value是否为空, 空且不为0则退出本次循环

        if (_this3._valueError(value)) {
          return "continue";
        }

        var fieldItem = _this3.fieldList.find(function (item) {
          return item.key + '' === key + '';
        }) || {}; // 下拉选项选择了全部不需要

        if (value === SELECT_ALL_VALUE && fieldItem.type === FORM_ITEM_TYPE.SELECT) {
          return "continue";
        }

        if (fieldItem.customRender) {
          value = fieldItem.customRender(value); // 判断value是否为空, 空且不为0则退出本次循环

          if (_this3._valueError(value)) {
            return "continue";
          }
        } // 判断moment时间类型转为时间戳


        if (value instanceof moment) {
          // console.log('时间戳转换')
          value = moment(value).valueOf();
        }

        if (isNaN(key)) {
          // 非数字类型的话就是特殊的搜索项
          resForm[key] = value;
        } else {
          var intKey = parseInt(key);
          var isVague = fieldItem.isVague || false;
          searchKeys.push({
            fieldNo: intKey,
            fieldValue: value,
            searchType: isVague ? SEARCH_TYPE.VAGUE : SEARCH_TYPE.PRECISE
          });
        }
      };

      for (var key in this.form) {
        var _ret = _loop(key);

        if (_ret === "continue") continue;
      }

      if (searchKeys.length > 0) {
        resForm.searchKeys = searchKeys;
      }

      return resForm;
    },

    /**
     * 重置，可供外部使用
     * 处理list,重置选择参数
     */
    reset: function reset() {
      this.form = _objectSpread({}, this.formData);
      this.$emit('reset', this.form);
    }
  }
};

==> better-admin-ui-vue-0.0.9.tgz: package/es/components/SearchBar/SearchBar.js <==
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * @Date: 2020/11/24 2:44 下午
 * @Author: Fioanna
 * @Description: 高级搜索表单
 * 支持的类型：InputNumber, Input, Radio, Select, Suggest, DateRange, CompactInput
 */
import moment from 'moment';
import ARow from 'ant-design-vue/es/row';
import ACol from 'ant-design-vue/es/col';
import ACard from 'ant-design-vue/es/card';
import AButton from 'ant-design-vue/es/button';
import AFormModal from 'ant-design-vue/es/form-model';
import { FORM_ITEM_TYPE, FormMixin } from '../Form';
import EMixedInput from '../MixedInput';
import searchBarProps from './types';
import { COL_2_ITEM_LIST, SELECT_ALL_VALUE, SEARCH_TYPE } from './constants';
import '../Form/style.less';
import './style.less';
var COL_TOTAL = 24; // 默认一行分为24份，可除尽1、2、3、4、6、8、12、24

var MD_COL = 2; // 栅格md

var XL_COL = 4; // 栅格xl

var AFormModalItem = AFormModal.Item; // 默认的展示时间格式

var DEFAULT_SHOW_FORMAT = 'YYYY-MM-DD HH:mm:ss';
export default {
  name: 'ESearchBar',
  mixins: [FormMixin],
  props: searchBarProps,
  computed: {
    // 表单v-bind的所有props
    formModelBind: function formModelBind() {
      return {
        layout: 'inline',
        model: this.form
      };
    }
  },
  render: function render() {
    var h = arguments[0];

    if (this.hasFieldList) {
      return h(ACard, {
        "class": "e-search-bar e-form"
      }, [h(AFormModal, _mergeJSXProps([{
        ref: "advancedForm"
      }, {
        props: this.formModelBind
      }]), [h(ARow, {
        attrs: {
          gutter: {
            xs: 8,
            sm: 16,
            md: 24
          }
        }
      }, [this._renderFormContent()])])]);
    }

    return null;
  },
  methods: {
    // 时间选择器
    _parseDateRange: function _parseDateRange(item, props) {
      props.showFormat = props.showFormat || DEFAULT_SHOW_FORMAT;
      props.valueFormat = props.valueFormat || null;

      if (props.showFormat === DEFAULT_SHOW_FORMAT) {
        // 如果是默认的有时分秒的格式则设定展示time
        props.showTime = true;
      } // 一般搜索栏都有时间选择限制
      // 如果没有明确说明不需要，且又未传入的，则默认设置一个disabledDate


      if (item.needDisabledDate !== false && !props.disabledDate) {
        // 限制的范围天数
        var limitRangeDays = item.limitRangeDays;
        var limitMethod = limitRangeDays ? function (current) {
          return current < moment().subtract(limitRangeDays, 'days').endOf('date');
        } : function () {
          return false;
        };

        props.disabledDate = function (current) {
          // 可以取到当天最后一秒
          return current && (current > moment().endOf('date') || limitMethod(current));
        };
      }
    },

    /**
     * 刷新普通下拉选项列表，可继承
     */
    _refreshSelectList: function _refreshSelectList(selectList, item, props) {
      // 需要添加全部选项
      if (item.needAll && selectList && selectList.length > 0) {
        // console.log('~~~selectList~~~', selectList)
        var valueName = props.valueName || 'value';

        if (selectList[0][valueName] !== SELECT_ALL_VALUE) {
          var _selectList$unshift;

          selectList.unshift((_selectList$unshift = {}, _defineProperty(_selectList$unshift, valueName, SELECT_ALL_VALUE), _defineProperty(_selectList$unshift, props.labelName || 'label', '全部'), _selectList$unshift));
        }
      }
    },

    /**
     * 刷新字典下拉选项列表，可继承
     */
    _refreshDictSelectList: function _refreshDictSelectList(selectList, item, props) {
      var itemDom = this.$refs[item.key]; // 直接更新下拉组件中的数据

      if (itemDom) {
        this._refreshSelectList(selectList, item, props);

        itemDom.setOptionList(selectList);
      }
    },
    // 初始化表单的单项
    _renderFormItem: function _renderFormItem(fieldItem, index) {
      var h = this.$createElement;
      var itemCol = 1;

      if (COL_2_ITEM_LIST.includes(fieldItem.type)) {
        itemCol = fieldItem.col || 2;
      }

      return h(ACol, {
        attrs: {
          sm: COL_TOTAL,
          md: COL_TOTAL / MD_COL * itemCol,
          xl: COL_TOTAL / XL_COL * itemCol
        }
      }, [h(AFormModalItem, {
        key: index,
        attrs: {
          label: fieldItem.label,
          prop: fieldItem.key + '',
          required: fieldItem.required,
          rules: fieldItem.rules
        }
      }, [this._renderFormItemContent(fieldItem)])]);
    },
    // 初始化表单footer的按钮部分
    _renderFormFooter: function _renderFormFooter() {
      var h = this.$createElement;
      var btnList = [h(AButton, {
        attrs: {
          icon: "search",
          type: "primary"
        },
        on: {
          "click": this._confirm
        }
      }, ["\u67E5\u8BE2"])];

      if (this.$props.needReset) {
        btnList.push(h(AButton, {
          attrs: {
            icon: "redo"
          },
          on: {
            "click": this.reset
          }
        }, ["\u91CD\u7F6E"]));
      }

      return h(ACol, {
        attrs: {
          sm: COL_TOTAL,
          md: COL_TOTAL / MD_COL,
          xl: COL_TOTAL / XL_COL
        }
      }, [h(AFormModalItem, {
        style: "margin:0;"
      }, [h("span", {
        "class": "search-btn-wrapper right"
      }, [btnList])])]);
    },
    // 初始化组合输入框
    _renderCompactInput: function _renderCompactInput(fieldItem) {
      var _this = this;

      var h = this.$createElement;
      return h(EMixedInput, _mergeJSXProps2([{
        props: fieldItem.props
      }, {
        attrs: {
          value: this.form[fieldItem.key]
        },
        on: {
          "change": function change(value, key, label, item) {
            if (label && item) {
              _this._emitChange(key, value, label, item);
            } else {
              _this._emitChange(key, value);
            }
          }
        }
      }]));
    },

    /**
     * 时间区间选择变动
     * @param key form的key
     * @param {Array} dates 指定日期格式的字符串，无格式则返回moment
     * @private
     */
    _dateRangeChange: function _dateRangeChange(item, dates) {
      var _this2 = this;

      var keys = item.keys,
          key = item.key;
      this.$set(this.form, key, 'date');
      dates.forEach(function (date, index) {
        if (item.showFormat !== DEFAULT_SHOW_FORMAT) {
          var momentParse = index === 0 ? 'startOf' : 'endOf';
          date[momentParse]('date');
        }

        _this2._emitChange(keys[index], date);
      });
    },

    /**
     * 点击查询
     * @private
     */
    _confirm: function _confirm() {
      this.$emit('search', this.getValue());
    },
    // 判断value是否为空
    _valueError: function _valueError(value) {
      return !value && value !== 0;
    },

    /**
     * 获取表单数据
     * @returns {form|{}}
     */
    getValue: function getValue() {
      var _this3 = this;

      var resForm = {};
      var searchKeys = [];

      var _loop = function _loop(key) {
        var value = _this3.form[key]; // 判断value是否为空, 空且不为0则退出本次循环

        if (_this3._valueError(value)) {
          return "continue";
        }

        var fieldItem = _this3.fieldList.find(function (item) {
          return item.key + '' === key + '';
        }) || {}; // 下拉选项选择了全部不需要

        if (value === SELECT_ALL_VALUE && fieldItem.type === FORM_ITEM_TYPE.SELECT) {
          return "continue";
        }

        if (fieldItem.customRender) {
          value = fieldItem.customRender(value); // 判断value是否为空, 空且不为0则退出本次循环

          if (_this3._valueError(value)) {
            return "continue";
          }
        } // 判断moment时间类型转为时间戳


        if (value instanceof moment) {
          // console.log('时间戳转换')
          value = moment(value).valueOf();
        }

        if (isNaN(key)) {
          // 非数字类型的话就是特殊的搜索项
          resForm[key] = value;
        } else {
          var intKey = parseInt(key);
          var isVague = fieldItem.isVague || false;
          searchKeys.push({
            fieldNo: intKey,
            fieldValue: value,
            searchType: isVague ? SEARCH_TYPE.VAGUE : SEARCH_TYPE.PRECISE
          });
        }
      };

      for (var key in this.form) {
        var _ret = _loop(key);

        if (_ret === "continue") continue;
      }

      if (searchKeys.length > 0) {
        resForm.searchKeys = searchKeys;
      }

      return resForm;
    },

    /**
     * 重置，可供外部使用
     * 处理list,重置选择参数
     */
    reset: function reset() {
      this.form = _objectSpread({}, this.formData);
      this.$emit('reset', this.form);
    }
  }
};
